'use strict';

Object.defineProperty(exports, '__esModule', {
    value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _ContentCache = require('./ContentCache');

var _ContentCache2 = _interopRequireDefault(_ContentCache);

var ContentHelper = {
    loadItem: function loadItem(url, callback) {
        var content = _ContentCache2['default'].get(url);

        return new Promise(function (resolve, reject) {
            var handleSuccess = function handleSuccess() {
                if (content.src.indexOf('m4a') > -1 || content.src.indexOf('ogg') > -1) {
                    content.muted = false;
                    content.pause();
                    content.removeEventListener('playing', handleSuccess, false);
                }
                if (callback) {
                    callback(true);
                }
                resolve(content);
            };
            var handleError = function handleError() {
                console.error('Content failed', content);
                if (callback) {
                    callback(false);
                }
                reject(content);
            };

            if (content.naturalWidth && content.naturalHeight || content.readyState === 4) {
                // content is loaded, go ahead and change the state
                handleSuccess();
            } else {
                if (content.src.indexOf('m4a') > -1 || content.src.indexOf('ogg') > -1) {
                    content.muted = true;
                    content.addEventListener('playing', handleSuccess, false);
                    content.play();
                } else {
                    content.addEventListener('load', handleSuccess, false);
                }
                content.addEventListener('error', handleError, false);
            }
        });
    },

    loadContent: function loadContent(urls, callback) {
        var _this = this;

        var promises = urls.map(function (url) {
            return _this.loadItem(url, callback);
        });
        return Promise.all(promises);
    },

    // preload without caring about the result
    stuffContent: function stuffContent(urls) {
        _ContentCache2['default'].stuff(urls);
    }
};

exports['default'] = ContentHelper;
module.exports = exports['default'];